View source: R/get_version_metadata.R
| get_version_metadata | R Documentation |
Prints information of a specific version of the FORCIS database by querying the Zenodo API (https://developers.zenodo.org).
get_version_metadata(version = NULL)
version |
a |
A list with all information about the version, including: title,
doi, publication_date, description, access_right, creators,
keywords, version, resource_type, license, and files.
# Get information for the latest version of the FORCIS database ----
get_version_metadata()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.